import { h } from "vue";
import { DescriptionColumns } from "/@/components/BasicDescriptions";
import { renderStatus } from "/@/utils/column-helper";
import { createTooltip } from "/@/utils/tooltip";
import { ElImage } from "element-plus";

import {
  isCustomizedOptions,
  isMultiAddrOptions,
  supplyAreaOptions,
  rateStatusOptions,
  sendWayOptions,
  statusOptions,
  payWayOptions
} from "./_options";

export const bargainColumns: DescriptionColumns = [
  {
    field: "bargainNo",
    label: "议价单编号",
    span: 6
  },

  {
    field: "bidsNo",
    label: "反馈商品编号",
    span: 6
  },
  {
    field: "infoNo",
    label: "竞价单编号",
    span: 6
  },
  {
    field: "status",
    label: "状态",
    span: 6,
    render: (_, row) => renderStatus(statusOptions).cellRenderer({ row })
  },
  {
    field: "creater",
    label: "创建人",
    span: 6
  },

  {
    field: "is_addrs",
    label: "是否多地",
    span: 4,
    render: (_, row) =>
      renderStatus(isMultiAddrOptions, "is_addrs").cellRenderer({ row })
  },
  {
    field: "is_custom",
    label: "是否定制",
    span: 4,
    render: (_, row) =>
      renderStatus(isCustomizedOptions, "is_custom").cellRenderer({ row })
  },
  {
    field: "good_num",
    label: "购买数量",
    span: 4,
    render(good_num, { unit }) {
      const num = good_num ?? "0";
      return num + unit;
    }
  },
  {
    field: "rate_status",
    label: "预计通过节点",
    span: 6,
    render: (_, row) =>
      renderStatus(rateStatusOptions, "rate_status").cellRenderer({ row })
  },
  {
    field: "addtime",
    label: "添加时间",
    span: 6
  },
  {
    field: "origin_addr",
    label: "产地",
    span: 6
  },
  {
    field: "result_info",
    label: "议价原因",
    span: 12
  },
  {
    field: "bargain_remark",
    label: "议价备注",
    span: 24
  },

  {
    field: "sale_price",
    label: "议价前售价",
    append: "元",
    span: 6
  },
  {
    field: "after_price",
    label: "议价后售价",
    append: "元",
    span: 6
  },

  {
    field: "cost_before_price",
    label: "议价前工艺费",
    append: "元",
    span: 6
  },

  {
    field: "cost_after_price",
    label: "议价后工艺费",
    append: "元",
    span: 6
  }
];

export const goodsColumns: DescriptionColumns = [
  {
    field: "good_name",
    label: "商品名称",
    span: 24,
    render(data, { spuCode }) {
      return createTooltip(data, `商品编号 : ${spuCode}`, 250);
    }
  },

  {
    field: "cat_info",
    label: "分类",
    span: 8,
    render(cat_info) {
      return cat_info?.map(({ name }) => name).join("_");
    }
  },

  {
    field: "brand_name",
    label: "品牌",
    span: 8
  },

  {
    field: "send_way",
    label: "发货方式",
    span: 8,
    render: (_, row) =>
      renderStatus(sendWayOptions, "send_way").cellRenderer({ row })
  },
  {
    field: "unit",
    label: "单位",
    span: 4
  },
  {
    field: "tax",
    label: "税点",
    append: "%",
    span: 4
  },
  {
    field: "pay_way",
    label: "付款方式",
    span: 4,
    render: (_, row) =>
      renderStatus(payWayOptions, "pay_way").cellRenderer({ row })
  },
  {
    field: "weight",
    label: "商品总克重",
    append: "g",
    span: 6
  },

  {
    field: "addtime",
    label: "反馈时间",
    span: 6
  },

  {
    field: "expire_day",
    label: "竞价有效期",
    append: "天",
    span: 4
  },

  {
    field: "delivery_day",
    label: "物流时间",
    append: "天",
    span: 4
  },
  {
    field: "work_day",
    label: "生产工期",
    append: "天",
    span: 4
  },
  {
    field: "cgder",
    label: "供应商负责人",
    span: 4
  },
  {
    field: "good_creater",
    label: "商品创建人",
    span: 4
  },

  {
    field: "supply_area",
    label: "供货区域",
    span: 4,
    render: (_, row) =>
      renderStatus(supplyAreaOptions, "supply_area").cellRenderer({ row })
  },

  {
    field: "good_img",
    label: "商品图片",
    span: 24,
    render: good_img => {
      return h(ElImage, {
        previewSrcList: [good_img],
        src: good_img,
        previewTeleported: true,
        style: {
          height: "20px",
          width: "20px"
        }
      });
    }
  },
  {
    field: "noble",
    label: "贵金属信息",
    span: 24,
    render(_, row) {
      const {
        noble_weight,
        noble_metal,
        noble_name,
        gold_price,
        is_gold_price,
        is_diff,
        config,
        other_config
      } = row;
      if (!noble_metal) {
        return "";
      }

      const weight = noble_weight ? `${noble_weight}g-${noble_name}` : "";

      const price = gold_price ? gold_price : "0";

      const isGoldPrice = is_gold_price === "0" ? "不" : "";

      const diff = is_diff === "1" ? "有" : "无";

      return `${weight}${price}元/g-${isGoldPrice}启用实时金价-${diff}工差-${config}-${other_config}`;
    }
  },
  {
    field: "cost_desc",
    label: "工艺说明",
    span: 24
  },
  {
    field: "remark",
    label: "采返备注",
    span: 24
  }
];

export const goodCostColumns: DescriptionColumns = [
  {
    field: "cert_fee",
    label: "成本证书费",
    append: "元",
    span: 6
  },
  {
    field: "pakge_fee",
    label: "成本包装费",
    append: "元",
    span: 6
  },
  {
    field: "cost_fee",
    label: "成本工艺费",
    append: "元",
    span: 6
  },
  {
    field: "mark_fee",
    label: "成本加标费",
    append: "元",
    span: 6
  },

  {
    field: "demo_fee",
    label: "成本打样费",
    append: "元",
    span: 6
  },
  {
    field: "open_fee",
    label: "成本开模费",
    append: "元",
    span: 6
  },
  {
    field: "delivery_fee",
    label: "成本物流费",
    append: "元",
    span: 6
  },
  {
    field: "nake_fee",
    label: "成本裸价",
    append: "元",
    span: 6
  },
  {
    field: "total_fee",
    label: "采购成本合计",
    append: "元",
    span: 24
  }
];

export const grossProfitColumns: DescriptionColumns = [
  {
    field: "before_rate",
    label: "议价前毛利率",
    append: "%",
    span: 12
  },

  {
    field: "after_rate",
    label: "议价后毛利率",
    append: "%",
    span: 12
  }
];
