import { ContentConfig } from "/@/components/PageContent";
import { httpList } from "/@/api/sellOut/salesOrder";
import { renderStatus } from "/@/utils/column-helper";
import { statusOptions } from "./_options";

import {
  XS_GOOD_SOURCE_OPTIONS,
  XS_ORDER_SOURCE_OPTIONS
} from "/@/config/status";

const columns = [
  {
    type: "selection",
    width: 55,
    hide: ({ checkList }) => !checkList.includes("勾选列")
  },
  {
    label: "序号",
    type: "index",
    width: 70,
    hide: ({ checkList }) => !checkList.includes("序号列")
  },
  {
    prop: "orderCode",
    label: "订单编号",
    width: "155px"
  },
  {
    prop: "good_name",
    label: "商品名称",
    _slot_: "good_name",
    width: "150"
  },
  {
    prop: "good_class",
    label: "商品分类",
    width: "120",
    cellRenderer({ row }) {
      return row.can.map(({ name }) => name).join("/");
    }
  },
  {
    prop: "good_num",
    width: "100",
    label: "商品数量"
  },
  {
    prop: "sale_price",
    width: "100",
    label: "销售单价"
  },
  {
    prop: "total_price",
    label: "总价"
  },
  {
    prop: "status",
    label: "订单状态",
    width: "120px",
    ...renderStatus(statusOptions)
  },

  {
    prop: "order_source",
    label: "订单来源",
    width: "100px",
    ...renderStatus(XS_GOOD_SOURCE_OPTIONS, "order_source")
  },
  {
    prop: "order_type",
    label: "商品来源",
    width: "100px",
    ...renderStatus(XS_ORDER_SOURCE_OPTIONS, "order_type")
  },
  {
    prop: "useage",
    label: "订单用途",
    width: "100px"
  },

  {
    prop: "customer_code",
    label: "客户公司编码",
    width: "155px"
  },
  {
    prop: "customerName",
    label: "企业客户名称",
    width: "125px"
  },
  {
    prop: "supplierName",
    label: "销售方公司",
    width: "125px"
  },
  {
    prop: "apply_name",
    label: "订单创建人",
    width: "100px"
  },
  {
    prop: "cgder",
    label: "供应商负责人",
    width: "120"
  },
  {
    prop: "good_creater",
    label: "商品创建人",
    width: "100"
  },
  {
    prop: "addtime",
    label: "创建时间",
    width: "145px"
  },
  {
    label: "操作",
    fixed: "right",
    width: "80px",
    slot: "operation"
  }
];

const contentConfig: ContentConfig = {
  title: "销售订单管理",
  columns,
  apis: {
    httpList
  }
};

export default contentConfig;
