import { ContentConfig } from "/@/components/PageContent";
import { httpList } from "/@/api/sellOut/sellOutOrder";
import { renderStatus } from "/@/utils/column-helper";
import { XS_ORDER_SOURCE_OPTIONS } from "/@/config/status";
import { statusOptions } from "./options";

const columns = [
  {
    type: "selection",
    width: 55,
    hide: ({ checkList }) => !checkList.includes("勾选列")
  },
  {
    label: "序号",
    type: "index",
    width: 70,
    hide: ({ checkList }) => !checkList.includes("序号列")
  },
  {
    prop: "outCode",
    label: "发货申请单编号",
    width: "180"
  },

  {
    prop: "orderCode",
    label: "订单编号",
    width: "180"
  },
  {
    prop: "cgdNo",
    label: "采购单编号",
    width: "180"
  },
  {
    prop: "company_name",
    label: "申请人部门",
    minWidth: "150px"
  },
  {
    prop: "wsm_supplier",
    label: "供应商",
    minWidth: "150px"
  },
  {
    prop: "apply_name",
    label: "申请人",
    width: "70px"
  },
  {
    prop: "status",
    label: "状态",
    width: "100",
    cellRenderer({ row }) {
      return renderStatus(statusOptions, row.status);
    }
  },
  {
    prop: "order_type",
    label: "商品来源",
    width: "100",
    cellRenderer({ row }) {
      return renderStatus(XS_ORDER_SOURCE_OPTIONS, row.order_type);
    }
  },
  {
    prop: "send_num",
    label: "发货数量",
    width: "100"
  },
  {
    prop: "good_class",
    label: "商品分类",
    width: "150",
    cellRenderer({ row }) {
      return row.can.map(({ name }) => name).join("/");
    }
  },
  {
    prop: "good_code",
    label: "商品编码",
    width: "180"
  },
  {
    prop: "good_name",
    label: "商品名称",
    width: "150"
  },
  {
    prop: "contactor",
    label: "联系人",
    width: "70"
  },
  {
    prop: "mobile",
    label: "联系电话",
    width: "100"
  },
  {
    prop: "post_name",
    label: "物流公司",
    width: "100"
  },
  {
    prop: "post_code",
    label: "物流单号",
    width: "100"
  },
  {
    prop: "post_fee",
    label: "物流费用"
  },
  {
    prop: "sendtime",
    label: "发货时间",
    width: "140"
  },

  {
    prop: "addtime",
    label: "添加时间",
    width: 150
  },
  {
    prop: "",
    label: "操作",
    fixed: "right",
    width: "80px"
  }
];

const contentConfig: ContentConfig = {
  title: "发货申请管理",
  columns,
  apis: {
    httpList
  },
  powers: ["001", "002", "003", "004", "005", "006", "007", "008"]
};

export default contentConfig;
